# Credits

Citing the well-deserved folks for being an influencer

- [@Abhishek Thakur](https://github.com/abhishekkrthakur/): inspiration from [his repo](https://github.com/abhishekkrthakur/wtfml) and [helpful videos (Tips and Tricks)](https://www.youtube.com/AbhishekThakurAbhi?sub_confirmation=1).
- [@Marco Gorelli](https://github.com/MarcoGorelli/): inspiration from [his repo](https://github.com/MarcoGorelli/nbQA/) to help with basic setup layout
- **[Raenish David](https://www.kaggle.com/raenish) for his inspiring [kernel](https://www.kaggle.com/raenish/cheatsheet-text-helper-functions) which lead to the inception of this library**
- [pandas-profiling](https://github.com/pandas-profiling/pandas-profiling) library for ideas about the various GitHub templates
- And the contributors to this repo for raising [issues](https://github.com/neomatrix369/nlp_profiler/issues) and [pull requests](https://github.com/neomatrix369/nlp_profiler/pulls).
- Not forgetting those who are [watching](https://github.com/neomatrix369/nlp_profiler/watchers), [starred](https://github.com/neomatrix369/nlp_profiler/stargazers) and [forked](https://github.com/neomatrix369/nlp_profiler/network/members) this repo

# Supporters and well wishers

See what others have to say about this library:

- [Complete Guide On NLP Profiler: Python Tool For Profiling of Textual Dataset](https://analyticsindiamag.com/complete-guide-on-nlp-profiler-python-tool-for-profiling-of-textual-dataset/), an article on [Analytics Vidya India Magazine]() by [Himanshu Sharma](https://analyticsindiamag.com/author/himanshu-sharmaanalyticsindiamag-com/)
- [LinkedIn post](https://www.linkedin.com/feed/update/urn:li:activity:6708394732621582336/) by [Philip Voilet](https://www.linkedin.com/in/philipvollet)
- [Tweet](https://twitter.com/kurianbenoy2/status/1300482632413667335) by [Kurian Benoy](https://in.linkedin.com/in/kurianbenoy)
- Kernel [NLP Profiler: A Python tool for profiling of Textual Dataset](https://www.kaggle.com/viratkothari/nlp-profiler-profiling-of-textual-dataset) by [Virat Kothari](https://www.kaggle.com/viratkothari/)

---

Return to [README.md](README.md)

